@@ -8,11 +8,13 @@ from django_extensions.tests.shortuuid_field import ShortUUIDFieldTest
 from django_extensions.tests.fields import AutoSlugFieldTest
 from django_extensions.tests.management_command import CommandTest, ShowTemplateTagsTests
 from django_extensions.tests.test_templatetags import TemplateTagsTests
+from django_extensions.tests.test_clean_pyc import CleanPycTests
+from django_extensions.tests.test_compile_pyc import CompilePycTests
 
 __test_classes__ = [
     DumpScriptTests, JsonFieldTest, UUIDFieldTest, AutoSlugFieldTest, CommandTest,
     ShowTemplateTagsTests, TruncateLetterTests, TemplateTagsTests, ShortUUIDFieldTest,
-    PostgreSQLUUIDFieldTest,
+    PostgreSQLUUIDFieldTest, CleanPycTests, CompilePycTests
 ]
 
 try:
